==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/ctabbar.cpp <==
/***************************************************************************
                          ctabbar.cpp -  manages tab bar
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Mon Nov 11 2003
    copyright            : (C) 2003 by Vladimir Lazarenko
    email                : kmuddy@kmuddy.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qtabbar.h>

#include <kapplication.h>
#include <klineeditdlg.h>
#include <klocale.h>
#include <kpopupmenu.h>

#include "ctabbar.h"

#include "csession.h"
#include "kmuddy.h"

extern KMuddy *kmuddy;

cTabBar::cTabBar(QWidget *parent, const char *name) : QTabBar(parent,name)
{
  popup=new KPopupMenu(this,"ctabbar_context_menu");
  if(popup)
  {
    popup->insertItem(i18n("Rename"), Rename);
    popup->insertItem(i18n("Disconnect"), Disconnect);
    popup->insertItem(i18n("Reconnect"), Reconnect);
    popup->insertItem(i18n("Close Tab"), CloseTab);
    popup->setItemEnabled(Reconnect, false);
  }
}

cTabBar::~cTabBar()
{
}

void cTabBar::contextMenuEvent(QContextMenuEvent *cevt)
{
  for(int index=0;index<count();index++)
  {
    QTab* lookTab=tabAt(index);
    if(lookTab->rect().contains(cevt->pos()))
    {
      popup->setItemEnabled(Reconnect, true);
      int r=popup->exec(cevt->globalPos());
      if (r == Rename)
      {
        bool ok;
        QString name = lookTab->text();
        name = KLineEditDlg::getText (i18n ("&Tab name"), name, &ok,
            KApplication::kApplication()->mainWidget());
        if (ok && (!name.isEmpty()))
        {
          int snum = kmuddy->getSessionByTab (index);
          kmuddy->setSessionName (snum, name, false);
        }
      }
      if(r==CloseTab)
      {
         emit closeTab();
      }
      if(r==Reconnect)
      {
        emit reConnect();
      }
      if(r==Disconnect)
      {
        emit disConnect();
      }
    }
  }
}

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/ctabbar.cpp <==
/***************************************************************************
                          ctabbar.cpp -  manages tab bar
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Mon Nov 11 2003
    copyright            : (C) 2003 by Vladimir Lazarenko
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qtabbar.h>

#include <kapplication.h>
#include <klineeditdlg.h>
#include <klocale.h>
#include <kpopupmenu.h>

#include "ctabbar.h"

#include "csessionmanager.h"

cTabBar::cTabBar(QWidget *parent, const char *name) : QTabBar(parent,name)
{
  setFocusPolicy (QWidget::NoFocus);
  popup=new KPopupMenu(this,"ctabbar_context_menu");
  if(popup)
  {
    popup->insertItem(i18n("Rename"), Rename);
    popup->insertItem(i18n("Disconnect"), Disconnect);
    popup->insertItem(i18n("Reconnect"), Reconnect);
    popup->insertItem(i18n("Close Tab"), CloseTab);
    popup->setItemEnabled(Reconnect, false);
  }
}

cTabBar::~cTabBar()
{
}

void cTabBar::contextMenuEvent(QContextMenuEvent *cevt)
{
  for(int index=0;index<count();index++)
  {
    QTab* lookTab=tabAt(index);
    if(lookTab->rect().contains(cevt->pos()))
    {
      popup->setItemEnabled(Reconnect, true);
      int r=popup->exec(cevt->globalPos());
      if (r == Rename)
      {
        bool ok;
        QString name = lookTab->text();
        name = KLineEditDlg::getText (i18n ("&Tab name"), name, &ok,
            KApplication::kApplication()->mainWidget());
        if (ok && (!name.isEmpty()))
        {
          int snum = cSessionManager::self()->getSessionByTab (index);
          cSessionManager::self()->setSessionName (snum, name, false);
        }
      }
      if(r==CloseTab)
      {
         emit closeTab();
      }
      if(r==Reconnect)
      {
        emit reConnect();
      }
      if(r==Disconnect)
      {
        emit disConnect();
      }
    }
  }
}
